---
image: /generated/articles-docs-paths-get-tangent-at-length.png
title: getTangentAtLength()
crumb: "@remotion/paths"
---

_Part of the [`@remotion/paths`](/docs/paths) package._

Gets tangent values `x` and `y` of a point which is on an SVG path. The first argument is an SVG path, the second one is the at which length the point should be sampled. It must be between 0 and the return value of [`getLength()`](/docs/paths/get-length).

Returns a point if the path is valid:

```tsx twoslash
import { getTangentAtLength } from "@remotion/paths";

const tangent = getTangentAtLength("M 50 50 L 150 50", 50);
console.log(tangent); // { x: 1, y: 0}
```

The function will throw if the path is invalid:

```tsx twoslash
import { getTangentAtLength } from "@remotion/paths";
// ---cut---
getTangentAtLength("remotion", 50); // Error: Malformed path data: ...
```

## Credits

Source code stems mostly from [svg-path-properties](https://www.npmjs.com/package/svg-path-properties).

## See also

- [getLength()](/docs/paths/get-length)
- [getPointAtLength()](/docs/paths/get-point-at-length)
- [`@remotion/paths`](/docs/paths)
- [Source code for this function](https://github.com/remotion-dev/remotion/blob/main/packages/paths/src/get-tangent-at-length.ts)
